@@ -1,7 +1,7 @@
 #'@title Correct Overloaded Peaks from GC-MS data.
 #'
 #'@description
-#'\code{CorrectOverloadedPeaks} will take an xcmsRaw data structure and search for overloaded peaks within the mass traces.
+#'\code{CorrectOverloadedPeaks} will take an xcmsRaw data structure (or any imported mzXML) and search for overloaded peaks within the mass traces.
 #'based on further parameters. It will correct overloaded peaks automatically using an Gaussian or IsotopicRatio approach,
 #'generate QC plots and write the corrected data back into the original xcmsRaw.
 #'
@@ -30,10 +30,6 @@
 #'An corrected xcmsRaw- or mzXML-object which can be exported to file. Additionally a QC-plot pdf-file if silent=FALSE.
 #'
 #'@examples
-#'#load xcmsRaw test data, then correct, plot and return reconstructed data
-#'data("xcmsRaw_data")
-#'\donttest{CorrectOverloadedPeaks(data=xcmsRaw_data, method="Gauss", silent=FALSE)}
-#'
 #'#load mzXML test data
 #'data(mzXML_data)
 #'\donttest{CorrectOverloadedPeaks(data=mzXML_data, method="EMG", silent=FALSE)}
@@ -152,7 +148,9 @@ function(data=NULL, method=c("Isoratio","Gauss","EMG")[1], detection_limit=1, ds
   if (class(data)=="xcmsRaw") {
     scannum <- as.integer(diff(c(data@scanindex, length(data@env$mz))))
     pks <- sapply(split(matrix(c(data@env$mz,data@env$intensity),ncol=2),factor(rep(1:length(scannum),times=scannum))),matrix,ncol=2)
-    inf <- data.frame("seqNum"=data@acquisitionNum,"retentionTime"=data@scantime,"basePeakMZ"=sapply(pks,function(x){x[which.max(x[,2])[1],1]}),"basePeakIntensity"=sapply(pks,function(x){max(x[,2])}))
+    # $$JL: fixed in V1.2.17$$
+    #inf <- data.frame("seqNum"=data@acquisitionNum,"retentionTime"=data@scantime,"basePeakMZ"=sapply(pks,function(x){x[which.max(x[,2])[1],1]}),"basePeakIntensity"=sapply(pks,function(x){max(x[,2])}))
+    inf <- data.frame("seqNum"=1:length(data@scanindex),"retentionTime"=data@scantime,"basePeakMZ"=sapply(pks,function(x){x[which.max(x[,2])[1],1]}),"basePeakIntensity"=sapply(pks,function(x){max(x[,2])}))
   }
   
   if (class(data)=="mzXML") {
